## Starting the Document this code challenge

I need help on this code. I only have so many hours in the day. Please be liberal about patching and hacking (and sharing code!) so we can all benefit. 

Docs patches are deeply appreciated. For now you can just stick Markdown files in the Docs directory.

# Evently

These are some vendor Evently widgets that are running on the CouchApp system.

## Account
  This is how you signup, login and logout without worry about the code.
  Todo, we could have this work against remote APIs like that Facebook stuff or whatever.


## Profile
  Use this to load the local users profile for the logged in user. Useful if you're going to be posting new messages. Most applications end up customizing `profile.profileReady` to render the primary data-entry form. This gets you benefits like refreshing on login / logout, etc, automatically.


## Docs
  This needs to be moved to it's own app.
  I have this vision of a docs app designed for offline editing, that involves each Markdown paragraph being it's own document, with automatic use of Bespin for code samples. Any help on this would be thanked much.
